*********************************************
* ECDC OPERATIONAL SUPPORT Tools and methods for promoting     vaccination acceptance and uptake: a social and behavioural * science approach #
********************************************************


** To use this analysis code, ensure that the variables are named according to the following list:
**Demographic variables:

*age 
*gender 
*education
*region // assign values according to the setting
*employment_status 

** Vaccination behavioural outcomes

*vaccinated 
*refused 
*intend 

** 5Cs indicators 

** Confidence

*conf1
*conf2
*conf3

** Complacency

*comp1 
*comp2 
*comp3 

** Constraints 

*cons1 
*cons2 
*cons3
 
** Calculation

*calc1 
*calc2 
*calc3 

** Collective responsibility

*coll1 
*coll2
*coll3 

* Load example dataset

use "example_data.dta", clear 


* Set missing values for "I do not know/Prefer not to say"
recode vaccinated refused intend conf1 conf2 conf3 comp1 comp2 comp3 cons1 cons2 cons3 calc1 calc2 calc3 coll1 coll2 coll3 (99=.)

recode gender (4=.)

* Reversing code for comp1, cons2, cons3, calc2, calc3, coll2 

replace comp1=6-comp1
replace cons2=6-cons2
replace cons3=6-cons3
replace calc2=6-calc2
replace calc3=6-calc3
replace coll2=6-coll2


label define c_reversed_lab 1 "Strongly agree" 2 "Agree" 3 "Neutral" 4 "Disagree" 5 "Strongly disagree"
label value comp1 cons2 cons3 calc2 calc3 coll2 c_reversed_lab

* Categorize age

gen age_group=1 if age>=18 & age<=25
replace age_group=2 if age>=26 & age<=40
replace age_group=3 if age>=41 & age<=64
replace age_group=4 if age>=64 

label define age_group_lab 1"18-25" 2"26-40" 3"41-64" 4"65+"
label value age_group age_group_lab

* Labeling variables and values

label define gender_lab 1 "Male" 2 "Female" 3 "Non-binary" 
label value gender gender_lab

label define education_lbl 1 "Low" 2 "Medium" 3 "High" // to be updated according to the setting
label values education education_lbl

label define employment_lbl 1 "Employed" 2 "Self-Employed" 3 "Out of work" 4 "Student" 5 "Retired" 6 "Unable to work" 7 "Other" //to be updated according to the setting
label values employment_status employment_lbl

label define vacc_lbl 1 "None" 2 "Some" 3 "All" 
label values vaccinated vacc_lbl
label values refused vacc_lbl

label define intend_lbl 1 "Definitely not" 2 "Probably not" 3 "Maybe" 4 "Probably yes" 5 "Definitely yes" 
label values intend intend_lbl

label define c_lbl 1 "Strongly disagree" 2 "Disagree" 3 "Neutral" 4 "Agree" 5 "Strongly agree" 
foreach var in conf1 conf2 conf3 comp1 comp2 comp3 cons1 cons2 cons3 calc1 calc2 calc3 coll1 coll2 coll3 {
    label values `var' c_lbl
}


* Generate mean scores on the 5Cs

gen confidence = (conf1 + conf2 + conf3) / 3

gen complacency = (comp1 + comp2 + comp3) / 3

gen constraints = (cons1 + cons2 + cons3) / 3

gen calculation = (calc1 + calc2 + calc3) / 3

gen collective_responsibility = (coll1 + coll2 + coll3) / 3



* Drop and recreate intended vaccination for multinomial logistic regression
capture drop intend_3cat vaccinated_3cat refused_3cat

gen intend_3cat = .
replace intend_3cat = 1 if inrange(intend, 1, 2)
replace intend_3cat = 2 if intend == 3
replace intend_3cat = 3 if inrange(intend, 4, 5)


label define intend_3cat_lab 1"Def./prob. not" 2"Neutral" 3"Prob./Def. yes"
label value intend_3cat intend_3cat_lab

**** Descriptive Data Analysis ****

* % vaccinated as recommended by age, gender, education, and region

tab vaccinated

tab age_group vaccinated, col

tab gender vaccinated, col

tab education vaccinated, col

tab region vaccinated, col

* % refused recommended vaccinations by age, gender, education, and region

tab refused

tab age_group refused, col

tab gender refused, col

tab education refused, col

tab region refused, col

* % intend to get vaccinated by age, gender, education, and region

tab intend 

tab age_group intend, col

tab gender intend, col

tab education intend, col

tab region intend, col

* Core Indicators: Confidence, Complacency, Constraints, Calculation, Collective Responsibility

* % agreeing with key 5C indicators (answered 4 or 5)
foreach var in conf1 comp1 cons1 calc1 coll1 {
    gen `var'_agree = (`var' == 4 | `var' == 5)
}

* Summarize agreement percentages for each item separately: the mean for each variable * represents the proportion of answers agreeing with key 5C indicators (answered 4 or 5)

tabstat conf1_agree comp1_agree cons1_agree calc1_agree   coll1_agree, stat(mean) format(%9.3f)

* Here the means for each variable represents the proportion of answers agreeing with key 5C indicators (answered 4 or 5)


* Mean scores of each C stratified by demographic variables

summ confidence complacency constraints calculation collective_responsibility

bysort age_group: summarize confidence complacency constraints calculation collective_responsibility

bysort gender: summarize confidence complacency constraints calculation collective_responsibility

bysort education: summarize confidence complacency constraints calculation collective_responsibility

bysort region: summarize confidence complacency constraints calculation collective_responsibility

bysort employment_status: summarize confidence complacency constraints calculation collective_responsibility

**** Inferential Data Analysis ****

**	Socio-demographic predictors for each C ***

* Socio-demographic predictors for each C (Linear Regression)
reg confidence i.age_group i.gender i.education i.region i.employment_status
reg complacency i.age_group i.gender i.education i.region i.employment_status
reg constraints i.age_group i.gender i.education i.region i.employment_status
reg calculation i.age_group i.gender i.education i.region i.employment_status
reg collective_responsibility i.age_group i.gender i.education i.region i.employment_status

* Regression analysis for predictors of vaccination. The choice of the model (i.e., ordinal logistic, multinomial or binary logistic regression) depends on theoretical and practical considerations

* Ordinal logistic regression for vaccination intention, refusal, and being vaccinated
ologit intend i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, or
ologit refused  i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, or
ologit vaccinated  i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, or

* Multinomial logistic regression for vaccination intention, refusal, and being vaccinated
mlogit intend_3cat i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, baseoutcome(1) rrr

mlogit refused i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, baseoutcome(1) rrr

mlogit vaccinated i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, baseoutcome(1) rrr

* Binary logistic regression for vaccination intention, refusal, and being vaccinated

recode intend (1/3=0 "Low" ) (4/5=1 "High" ), gen(intend_binary)
recode vaccinated (0/1=0 "None or Some" ) (2=1 "Fully Vaccinated" ), gen(vaccinated_binary)
recode refused (0/1=0 "None or Some" ) (2=1 "Fully Refused" ), gen(refused_binary)

logit intend_binary i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, or

logit refused_binary i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, or

logit vaccinated_binary i.age_group i.gender i.education i.region i.employment_status confidence complacency constraints calculation collective_responsibility, or
